@@ -41,7 +41,7 @@ sub new {
 		Data => $data,
 	};
 	PDL::Primitive::axisvalues($this->{Vertices}->slice('(0),:,:'));
-	PDL::Primitive::axisvalues($this->{Vertices}->slice('(1),:,:')->transpose);
+	PDL::Primitive::axisvalues($this->{Vertices}->slice('(1),:,:')->xchg(0,1));
 	PDL::Ops::assgn($this->{Data},$this->{Vertices}->slice('(2),:,:'));
 	bless $this,$type;
 }
