@@ -4,7 +4,7 @@ PDL::Gaussian -- Gaussian distributions.
 
 =head1 SYNOPSIS
 
- $x = PDL::Gaussian->new([3],[5]);
+ $x = new PDL::Gaussian([3],[5]);
  $x->set_covariance(...)
 
 =head1 DESCRIPTION
@@ -14,15 +14,15 @@ sets gaussian distributions.
 
 A new set of gaussians is initialized by
 
- $x = PDL::Gaussian->new(xdims,gdims);
+ $x = new PDL::Gaussian(xdims,gdims);
 
 Where I<xdims> is a reference to an array containing the
 dimensions in the space the gaussian
 is in and I<gdimslist> is a reference to an array containing
 the dimensionality of the gaussian space. For example, after
 
- $x = PDL::Gaussian->new([2],[3,4]);
- $y = PDL::Gaussian->new([],[]);
+ $x = new PDL::Gaussian([2],[3,4]);
+ $y = new PDL::Gaussian([],[]);
 
 The variable C<$x> contains set of 12 (=C<3*4>) 2-Dimensional gaussians
 and C<$y> is the simplest form: one 1D gaussian.
@@ -116,12 +116,11 @@ the copyright notice should be included in the file.
 =cut
 
 package PDL::Gaussian;
-use strict;
-use warnings;
 use PDL::Core '';
 use PDL::Slatec;
 use PDL::Primitive;
 use PDL::Slices;
+# use PDL::Lib::LLSQRout;
 
 sub new {
 	my($type,$ndims,$nfuncs) = @_;
@@ -130,12 +129,12 @@ sub new {
 	}
 	my $ndims1 = ($#{$ndims==0} ? $ndims : [1]);
 	bless {
-		Mu => PDL->zeroes(PDL::double, @$ndims1,@$nfuncs),
-		ICV => PDL->zeroes(PDL::double, @$ndims1,@$ndims1,@$nfuncs),
-		CV => PDL->zeroes(PDL::double, @$ndims1,@$ndims1,@$nfuncs),
-		lnPrefactor=> PDL->zeroes(PDL::double, @$nfuncs),
-		EigVec => PDL->zeroes(PDL::double, @$ndims1,@$ndims1,@$nfuncs),
-		EigVal => PDL->zeroes(PDL::double, @$ndims1,@$nfuncs),
+		Mu => (PDL->zeroes (@$ndims1,@$nfuncs)->double),
+		ICV => (PDL->zeroes (@$ndims1,@$ndims1,@$nfuncs)->double),
+		CV => (PDL->zeroes (@$ndims1,@$ndims1,@$nfuncs)->double),
+		lnPrefactor=> (PDL->zeroes(@$nfuncs)->double),
+		EigVec => (PDL->zeroes (@$ndims1,@$ndims1,@$nfuncs)->double),
+		EigVal => (PDL->zeroes (@$ndims1,@$nfuncs)->double),
 		NDims => $ndims,
 		NFuncs => $nfuncs,
 	},$type;
@@ -193,9 +192,9 @@ sub upd_icovariance {
 sub _eigs {
 	my($this,$mat) = @_;
 	my $tmpvec = $this->{EigVec}->float;
-	my $fvone = PDL->zeroes(PDL::float, @{$this->{NDims}});
-	my $fvtwo = PDL->zeroes(PDL::float, @{$this->{NDims}});
-	my $ierr = PDL->zeroes(PDL::long, @{$this->{NFuncs}});
+	my $fvone = (PDL->zeroes(@{$this->{NDims}}))->float;
+	my $fvtwo = (PDL->zeroes(@{$this->{NDims}}))->float;
+	my $ierr = (PDL->zeroes(@{$this->{NFuncs}}))->long;
 	my $tmp = $mat->float; # Copy, since is destroyed.
 	my $tmpval = $this->{EigVal}->float;
 
@@ -212,12 +211,12 @@ sub _otrans {
 	my $tmp = PDL->null;
 	$tmp .= $this->{EigVec}; my $foo;
 	if($inv) {
-		($foo = $tmp->broadcast(0)) /= $this->{EigVal};
+		($foo = $tmp->thread(0)) /= $this->{EigVal};
 	} else {
-		($foo = $tmp->broadcast(0)) *= $this->{EigVal};
+		($foo = $tmp->thread(0)) *= $this->{EigVal};
 	}
-	PDL::Primitive::inner($this->{EigVec}->broadcast(0,-1),$tmp->broadcast(-1,0),
-		$this->{($inv?"ICV":"CV")}->broadcast(0,1));
+	PDL::Primitive::inner($this->{EigVec}->thread(0,-1),$tmp->thread(-1,0),
+		$this->{($inv?"ICV":"CV")}->thread(0,1));
 }
 
 # Calculate prefactor.
@@ -242,15 +241,15 @@ sub calc_value ($$$) {
 sub calc_lnvalue ($$$) {
 	my($this,$xorig,$p) = @_;
 	my $x = $xorig;
-	my $muxed = PDL->zeroes(PDL::double, @{$this->{NDims}},@{$p->{Dims}});
+	my $muxed = (PDL->zeroes(@{$this->{NDims}},@{$p->{Dims}}))->double;
 
 #	print "MUXED1: $muxed\n";
 
-	my $arg11 = $this->{Mu}->broadcast(1..$#{$this->{NFuncs}}+1);
-	my $arg12 = $muxed->broadcast(1..$#{$this->{NFuncs}}+1);
+	my $arg11 = $this->{Mu}->thread(1..$#{$this->{NFuncs}}+1);
+	my $arg12 = $muxed->thread(1..$#{$this->{NFuncs}}+1);
 
-#	my_biop1($x,$this->{Mu}->broadcast(1..$#{$this->{NFuncs}}+1),
-#		$muxed->broadcast(1..$#{$this->{NFuncs}}+1),"-");
+#	my_biop1($x,$this->{Mu}->thread(1..$#{$this->{NFuncs}}+1),
+#		$muxed->thread(1..$#{$this->{NFuncs}}+1),"-");
 
 	print "TOINNER1\n";
 	PDL::Ops::my_biop1($x, $arg11, $arg12, "-");
@@ -258,16 +257,16 @@ sub calc_lnvalue ($$$) {
 	print "TOINNER2\n";
 #	print "MUXED: $muxed\n";
 	print "TOINNER2\n";
-	my $arg1 = ($muxed->broadcast(1..$#{$this->{NFuncs}}+1));
+	my $arg1 = ($muxed->thread(1..$#{$this->{NFuncs}}+1));
 	print "TOINNER3\n";
-	my $arg2 = ($this->{ICV}->broadcast(2..$#{$this->{ICV}{Dims}}));
+	my $arg2 = ($this->{ICV}->thread(2..$#{$this->{ICV}{Dims}}));
 	print "TOINNER4\n";
-	my $arg3 = ($p->broadcast(0..$#{$this->{NFuncs}}));
+	my $arg3 = ($p->thread(0..$#{$this->{NFuncs}}));
 	print "TOINNER5\n";
-#	inner2(($muxed->broadcast(1..$#{$this->{NFuncs}}+1))
-#		,($this->{ICV}->broadcast(2..$#{$this->{ICV}{Dims}})),
-#		($muxed->broadcast(1..$#{$this->{NFuncs}}+1))
-#		   ($p->broadcast(0..$#{$this->{NFuncs}})));
+#	inner2(($muxed->thread(1..$#{$this->{NFuncs}}+1))
+#		,($this->{ICV}->thread(2..$#{$this->{ICV}{Dims}})),
+#		($muxed->thread(1..$#{$this->{NFuncs}}+1))
+#		   ($p->thread(0..$#{$this->{NFuncs}})));
 	PDL::Primitive::inner2($arg1,$arg2,$arg1,$arg3);
 	print "FROMINNER2\n";
 	$p /= -2;
@@ -280,22 +279,22 @@ sub calc_lnvalue ($$$) {
 sub calc_lccovariance {
 	my($this,$vec,$var) = @_;
 	my $tmp = PDL->null;
-	inner2t($vec->transpose->broadcast(3..$#{$this->{NFuncs}}+3),
-		$this->{CV}->broadcast(2..$#{$this->{NFuncs}}+2),
-		$vec->broadcast(3..$#{$this->{NFuncs}}+3),
+	inner2t($vec->xchg(0,1)->thread(3..$#{$this->{NFuncs}}+3),
+	    	 $this->{CV}->thread(2..$#{$this->{NFuncs}}+2),
+		$vec->thread(3..$#{$this->{NFuncs}}+3),
 		$tmp,
-		$var->broadcast(3..$#{$this->{NFuncs}}+3));
+		$var->thread(3..$#{$this->{NFuncs}}+3));
 }
 
 # (nvars,newndims,foo) => (newndims,@gdims,foo)
-# (nvars,@xdims)->broadcast) -> (@gdims)
+# (nvars,@xdims)->thread) -> (@gdims)
 sub calc_lcavg {
 	my($this,$vec,$var) = @_;
 #	kill INT,$$;
 	PDL::Primitive::inner(
-		$vec->broadcast(3..$#{$this->{NFuncs}}+3),
-		$this->{Mu}->broadcast(1..$#{$this->{Mu}{Dims}}),
-		$var->broadcast(2..$#{$this->{NFuncs}}+2));
+		$vec->thread(3..$#{$this->{NFuncs}}+3),
+		$this->{Mu}->thread(1..$#{$this->{Mu}{Dims}}),
+		$var->thread(2..$#{$this->{NFuncs}}+2));
 }
 
 # Calculate the average of a second-degree term x^T M x
@@ -311,19 +310,19 @@ sub calc_qavg {
 	my $tmp2 = PDL->zeroes(@{$this->{NDims}},@{$this->{NDims}},
 		@cdims, @{$this->{NFuncs}});
 	PDL::Primitive::inner2t(
-			$this->{EigVec}->transpose,
-			$terms->broadcast(@cids),
+			$this->{EigVec}->xchg(0,1),
+			$terms->thread(@cids),
 			$this->{EigVec},
 			$tmp1,
-			$tmp2->broadcast(@cids)
+			$tmp2->thread(@cids)
 	);
 	$tmp2->flush();
-# Now, pick the diagonal of $tmp2, broadcasting over the unwanted dims..
-	my $diag = $tmp2->broadcast(@cids)->diagonal(0);
+# Now, pick the diagonal of $tmp2, threading over the unwanted dims..
+	my $diag = $tmp2->thread(@cids)->diagonal(0);
 # And multiply it by the covariance eigenvalues.
 	$diag *= $this->{EigVal};
 # Return the sum
-	$diag = $diag->unbroadcast(1);
+	$diag = $diag->unthread(1);
 	$diag->sumover($res);
 }
 
@@ -350,9 +349,12 @@ sub fromweighteddata {
 	my($this,$data,$wt) = @_;
 }
 
-sub ph {my($x) = @_; for (sort keys %$x) {next if !ref $x->{$_} or
+sub ph {my($x) = @_; for (keys %$x) {next if !ref $x->{$_} or
 	(ref $x->{$_}) eq "ARRAY";
    print "$_ :",$x->{$_},"\n	Dims:[",
 	(join ',',@{$x->{$_}{Dims}}),"]\n";}}
 
 1;
+
+
+
